
#include <avr/io.h>

#include <util/delay.h>

#ifndef F_CPU

//define cpu clock speed if not defined

#define F_CPU 8000000

#endif

//set desired baud rate

#define BAUDRATE 1200

//calculate UBRR value

#define UBRRVAL ((F_CPU/(BAUDRATE*16))-1) //16ul

//define receive parameters

#define SYNC 0XAA// synchro signal

#define RADDR 0x44

#define LEDON 0x11//switch led on command

#define LEDOFF 0x22//switch led off command

void USART_Init(void)

{

	//Set baud rate. UBRR is Baud Rate Register 

	UBRRL=(uint8_t)UBRRVAL;		//low byte

	UBRRH=(UBRRVAL>>8);	//high byte

	//Set data frame format: asynchronous mode,no parity, 1 stop bit, 8 bit size

	//USART transmitter is enabled by setting TXEN bit in UCSRB register.
	
	//When the function writes to the UCSRC Register, the URSEL bit (MSB) must be set due to
    //the sharing of I/O location by UBRRH and UCSRC.
	//UMSEL is USART Mode Select. 0=asynchronous, 1=synchronous.
	//UPM1:0 is parity mode. See p. 170 of user manual. 00=disabled (for now)   
	//USBS is number of stop bits inserted by transmitter. 
    //UCSZ2:0 is number of data bits. 011=8 bits, the maximum for low-speed USB.	

	UCSRC=(1<<URSEL)|(0<<UMSEL)|(0<<UPM1)|(0<<UPM0)|

		(0<<USBS)|(0<<UCSZ2)|(1<<UCSZ1)|(1<<UCSZ0);	

	//Enable Transmitter and Receiver and Interrupt on receive complete

	UCSRB=(1<<TXEN);

}

void USART_vSendByte(uint8_t data)

{

    // Wait if a byte is being transmitted

    while((UCSRA&(1<<UDRE)) == 0);

    // Transmit data

	//unsigned char[5] outstring;                     //the char array that will store the converted number
                         

    //itoa(data,outstring,10);

    //UDR = outstring;  

	UDR=data;

}

void Send_Packet(uint8_t addr, uint8_t cmd)

{

	USART_vSendByte(SYNC);//send synchro byte	

	USART_vSendByte(addr);//send receiver address

	USART_vSendByte(cmd);//send increment command

	USART_vSendByte((addr+cmd));//send checksum


}

void delayms(uint8_t t)//delay in ms

{

uint8_t i;

for(i=0;i<t;i++)

	_delay_ms(1);

}

int main(void)

{

USART_Init();

while(1)

	{//endless transmission

	//send command to switch led ON

	Send_Packet(RADDR, LEDON);

	delayms(100);

	//send command to switch led ON

	Send_Packet(RADDR, LEDOFF);

	delayms(100);

	}

	return 0;

}
